@@ -24,6 +24,7 @@
 #include "protocols/lircprotocol.h"
 #include "protocols/giprotocol.h"
 #include "protocols/necprotocol.h"
+#include "protocols/canalsatprotocol.h"
 
 
 Motorola4DTV::Motorola4DTV(
@@ -246,6 +247,71 @@ void MotorolaSTB1b::populateProtocol(
 }
 
 
+MotorolaSTB2::MotorolaSTB2(
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "STB Keyset 2",
+      Motorola_Make,
+      index)
+{
+}
+
+
+void MotorolaSTB2::populateProtocol(
+  QObject *guiObject)
+{
+  if (threadableProtocol)
+  {
+    // Keyset already populated.
+    return;
+  }
+
+  threadableProtocol = new CanalSatProtocol(guiObject, index);
+
+  setPreData(0x0940, 13);
+
+  addKey("1", One_Key, 0x01, 6);
+  addKey("2", Two_Key, 0x02, 6);
+  addKey("3", Three_Key, 0x03, 6);
+  addKey("4", Four_Key, 0x04, 6);
+  addKey("5", Five_Key, 0x05, 6);
+  addKey("6", Six_Key, 0x06, 6);
+  addKey("7", Seven_Key, 0x07, 6);
+  addKey("8", Eight_Key, 0x08, 6);
+  addKey("9", Nine_Key, 0x09, 6);
+  addKey("0", Zero_Key, 0x0A, 6);
+  addKey("power", Power_Key, 0x0B, 6);
+  addKey("up arrow", Up_Key, 0x0C, 6);
+  addKey("down arrow", Down_Key, 0x0D, 6);
+  addKey("left arrow", Left_Key, 0x0E, 6);
+  addKey("select", Select_Key, 0x0F, 6);
+
+  addKey("right arrow", Right_Key, 0x10, 6);
+  addKey("last (prev ch)", PrevChannel_Key, 0x13, 6);
+  addKey("Exit", Exit_Key, 0x13, 6);
+  addKey("program guide", Guide_Key, 0x16, 6);
+  addKey("vol up", VolumeUp_Key, 0x17, 6);
+  addKey("mute", Mute_Key, 0x18, 6);
+  addKey("channel up", ChannelUp_Key, 0x19, 6);
+  addKey("vol down", VolumeDown_Key, 0x1A, 6);
+  addKey("play", Play_Key, 0x1B, 6);
+  addKey("pause", Pause_Key, 0x1B, 6);
+  addKey("channel down", ChannelDown_Key, 0x1C, 6);
+  addKey("red", Red_Key, 0x1D, 6);
+  addKey("green", Green_Key, 0x1E, 6);
+  addKey("yellow", Yellow_Key, 0x1F, 6);
+
+  addKey("blue", Blue_Key, 0x20, 6);
+  addKey("rewind", Rewind_Key, 0x21, 6);
+  addKey("stop", Stop_Key, 0x22, 6);
+  addKey("record", Record_Key, 0x23, 6);
+  addKey("fast fwd", FastForward_Key, 0x24, 6);
+  addKey("TeleText", Teletext_Key, 0x29, 6);
+  addKey("Radio", TunerInput_Key, 0x2B, 6);
+  addKey("menu", Menu_Key, 0x2D, 6);
+}
+
+
 MotorolaSkyDigital::MotorolaSkyDigital(
   unsigned int index)
   : PIRKeysetMetaData(
