@@ -1,10 +1,25 @@
 // mainwindow.cpp
 //
-// For the Pierogi IR remote control app.
+// This is the main window code for the Pierogi Universal IR App.
 //
-// Copyright (C) 2012 by John Pietrzak  (john@pietrzak.org)
+// Copyright 2012, 2013 by John Pietrzak  (jpietrzak8@gmail.com)
+//
+// This file is part of Pierogi.
+//
+// Pierogi is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either version 2
+// of the License, or (at your option) any later version.
+//
+// Pierogi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// Licensed under the GNU GPL version 2.0 or later.
 
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
@@ -960,6 +975,19 @@ void MainWindow::gotoNextTabs()
 }
 */
 
+void MainWindow::setCarrierFrequency(
+  unsigned int freq)
+{
+  myKeysets->setCarrierFrequency(freq, currentKeyset);
+}
+
+
+void MainWindow::setDutyCycle(
+  unsigned int dc)
+{
+  myKeysets->setDutyCycle(dc, currentKeyset);
+}
+
  
 /*
 void MainWindow::keyPressEvent(
